#!/bin/sh
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2011 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of Medialogic S.p.A.                    #
#                                                                          #
#  All rigths reserved.                                                    #
#                                                                          #
############################################################################
PATH="/usr/bin:/bin:/usr/local/bin" && export PATH
NODE_ROOT='/usr/NX'
CONFIG_FILE="$NODE_ROOT/etc/node.cfg"
COMMAND_ECHO="/bin/echo"
COMMAND_SHARE_MOUNT="/bin/$7"
COMMAND_STAT="stat"

if [ ! -x $COMMAND_SHARE_MOUNT ];
then
  if [ -x "/sbin/$7" ];
  then
    COMMAND_SHARE_MOUNT="/sbin/$7"
  elif [ -x "/usr/sbin/$7" ];
  then
    COMMAND_SHARE_MOUNT="/usr/bin/u$7"
  elif [ -x "/usr/bin/$7" ];
  then
    COMMAND_SHARE_MOUNT="/usr/bin/$7"
  elif [ -x "/usr/local/bin/$7" ];
  then
    COMMAND_SHARE_MOUNT="/usr/local/bin/$7"
  elif [ -x "/usr/local/sbin/$7" ];
  then
    COMMAND_SHARE_MOUNT="/usr/local/sbin/$7"
  else 
    echo "Error: Cannot mount share $3, missing command $COMMAND_SHARE_MOUNT in $PATH. Cannot use NX smb privilegd script to mount shares."
    exit 1
  fi
fi

checkPpid() {

  if [ "x$1" = "x" ];
  then
    $COMMAND_ECHO "Missing pid"
    return 1
  fi
  if [ ! -e /proc/$1/cmdline ];
  then
    $COMMAND_ECHO "Wrong pid: $1"
    return 1
  fi

  command=$(/bin/cat /proc/$1/cmdline)

  $COMMAND_ECHO "$command"
}

command=$(checkPpid $2)

if [ $? != 0 ];
then
  $COMMAND_ECHO "NX> 500 Error: $command"
  exit 1
fi

if [ "$command" != "$NODE_ROOT/bin/nxnode" ];
then
  $COMMAND_ECHO "NX> 500 Error: Only the nxnode or nxserver can run this script.\n";
  exit 1
fi

if [ ! -r $CONFIG_FILE ];
then
  $COMMAND_ECHO "Error: Unable to read file $CONFIG_FILE"
  exit 1
fi

if [ -x "/bin/stat" ];
then
  COMMAND_STAT="/bin/stat"
elif [ -x "/usr/bin/stat" ];
then
  COMMAND_STAT="/usr/bin/stat"
elif [ -x "/usr/local/bin/stat" ];
then
  COMMAND_STAT="/usr/local/bin/stat"
else 
  echo "Error: Cannot stat owner of $4, missing command $COMMAND_STAT in $PATH. Cannot use NX smb privilegd script to mount share $3"
  exit 1
fi

MYSHARE=`grep '^ *SHARE_BASE_PATH' $CONFIG_FILE|sed -e 's|SHARE_BASE_PATH = ||g'|sed -e 's|\"||g'|sed -e 's|\$(HOME)|'$HOME'|g'|sed -e 's|\$(USER)|'$USER'|g'`
if [ $? != 0 ];
then
  MYSHARE="$HOME/MyShares"
fi
path_1=$MYSHARE
path_2=$4

if [ ! -d  "$path_2" ];
then
  $COMMAND_ECHO "Error: path: $path_2 does not exist or is not a directory."
  exit 1
else
  path_3=`cd "$path_2" && pwd -P`
  if ! $COMMAND_ECHO $path_3 | grep -q "^$path_1"
  then
   $COMMAND_ECHO "Error: Mount not allowed in $path_3 . Mount allowed only in $path_1."
   exit 1
  fi
fi

#command="stat --version"
#outCommand=`/bin/bash -c "$command" 2>&1`

outCommand=`stat --version 2>&1 `

if [ $? != 0 ];
then
  OWNER=` ls -lLd  "$path_2" | awk '{ print $3 }' `
else
  OWNER=`$COMMAND_STAT -L -c %U "$path_2"`
fi

###OWNER=`$COMMAND_STAT -L -c %U "$path_2"`

if [ x$OWNER != x$1 ];
then
  $COMMAND_ECHO "NX> 599 Error: $path_3 is owned by $OWNER instead of $USER." 1>&2
  $COMMAND_ECHO "NX> 599 Error: cannot mount share in $path_3: permission denied." 1>&2
  exit 1
else  
  #$COMMAND_ECHO "NX> 700 Info: mounting $2 on $3." 1>&2
  exec $COMMAND_SHARE_MOUNT "$3" "$4" "$5" "$6"
fi
