#!/bin/sh
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2011 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of Medialogic S.p.A.                    #
#                                                                          #
#  All rigths reserved.                                                    #
#                                                                          #
############################################################################

NODE_ROOT='/usr/NX'

CONFIG_FILE="$NODE_ROOT/etc/node.cfg"

LPADMIN_TIMEOUT=30

EX_USER=$1
EX_PID=$2
USER=$3
NAME="$EX_USER"_"$4"
MODEL=$5
PUBLIC=$6

if test $# -ne 6; then
  echo "Error: Wrong parameters count." && exit 1
fi

if [ -x "/usr/bin/whoami" ];
then
  WHOAMI="/usr/bin/whoami"
elif [ -x "/usr/ucb/whoami" ];
then
  WHOAMI="/usr/ucb/whoami"
else 
  echo "Error: Cannot find: 'whoami' in /usr/bin:/usr/ucb"
  exit 1
fi

EXS_USER=`$WHOAMI`

if [ "x$USER" = "x" ];
then
  echo "Error: Argument username cannot be empty."
  exit 1
fi

if test $EX_USER != $USER -o $EXS_USER != $USER ; then
  echo "Error: You can add or delete printer only for yourself." && exit 1
fi

if [ "x$NAME" = "x" ];
then
  echo "Error: Argument printer name cannot be empty."
  exit 1
fi
if [ $# -eq 6 ];
then

  if [ "x$MODEL" = "x" ];
  then
    echo "Error: Argument model name cannot be empty."
    exit 1
  fi

  if [ "x$PUBLIC" = "x" ];
  then
    echo "Error: Argument address cannot be empty."
    exit 1
  fi
fi

if [ -x "/usr/bin/expr" ];
then
  EXPR="/usr/bin/expr"
elif [ -x "/bin/expr" ];
then
  EXPR="/bin/expr"
elif [ -x "/usr/local/bin/expr" ];
then 
  EXPR="/usr/local/bin/expr"
else 
  echo "Error: Cannot find 'expr' in /bin:/usr/bin:/usr/local/bin"
  exit 1
fi

if [ -x "/bin/sleep" ];
then
  SLEEP="/bin/sleep"
elif [ -x "/usr/bin/sleep" ];
then
  SLEEP="/usr/bin/sleep"
else
  echo "Error: Cannod find 'sleep; in: /bin:/usr/bin"
  exit 1
fi

#grep CONFIG_FILE_VERSION $CONFIG_FILE > /dev/null

#if [ $? -eq 0 ]
#then
#  tmp=`/usr/bin/awk -F'"' '/^CUPS_SBIN/ {print $2}' $CONFIG_FILE`
#else
#  tmp=`/usr/bin/awk -F'"' '/^CUPSSbin/ {print $2}' $CONFIG_FILE`
#fi

tmp=`/usr/bin/awk -F'"' '/^CUPSSbin/ {print $2}' $CONFIG_FILE`

if [ "x$tmp" != "x" ];
then
  LPADMIN="$tmp/lpadmin"
else
  echo "CUPS support not configured correctly" && exit 1
fi

if test ! -x $LPADMIN ; then
  echo "Error: Wrong PATH for lpadmin binary." && exit 1
fi

parentPid=$$

read DEVICE_URI
if test "$PUBLIC" = "1" ;
then
  PUBLIC="" ;
else 
  PUBLIC="-u allow:$USER" ;
fi

export GATEWAY_INTERFACE="CGI/1.1"

$LPADMIN -p "$NAME" -E -v "$DEVICE_URI" -m "$MODEL" $PUBLIC &
lpPid=$!

(
  i=$LPADMIN_TIMEOUT
  while [ $i -gt 0 ]; do
    kill -0 $lpPid 2>/dev/null
    last=$?
    if [ "$last" -ne 0 ];
    then
      exit
    fi
    i=`$EXPR $i - 1`
    $SLEEP 1
  done
  echo "Error: Timeout of $LPADMIN_TIMEOUT seconds when running lpadmin: killing lpadmin"
  kill -9 $lpPid 2>/dev/null
) &

wait $lpPid 2>/dev/null
